@@ -10,7 +10,7 @@ use Exporter 'import';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-02-25'; # DATE
 our $DIST = 'App-BPOMUtils-RPO-Ingredients'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(
                        bpom_rpo_ingredients_group_for_label
@@ -113,7 +113,7 @@ sub bpom_rpo_ingredients_group_for_label {
         push @rows, [$ingredient, $ingredients{$group}{weight}];
     }
 
-    [200, "OK", \@rows, {'table.fields'=>['No', 'Ingredient', '%weight']}];
+    [200, "OK", \@rows, {'table.fields'=>['Ingredient', '%weight']}];
 }
 
 1;
@@ -131,7 +131,7 @@ App::BPOMUtils::RPO::Ingredients - Group ingredients suitable for food label
 
 =head1 VERSION
 
-This document describes version 0.002 of App::BPOMUtils::RPO::Ingredients (from Perl distribution App-BPOMUtils-RPO-Ingredients), released on 2024-02-25.
+This document describes version 0.003 of App::BPOMUtils::RPO::Ingredients (from Perl distribution App-BPOMUtils-RPO-Ingredients), released on 2024-02-25.
 
 =head1 SYNOPSIS
 
